package net.dotmyself.wsclient;

import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.xml.ws.AsyncHandler;
import javax.xml.ws.Response;
import net.dotmyself.ws.Department;
import net.dotmyself.ws.DepartmentInformationService;
import net.dotmyself.ws.DepartmentService;
import net.dotmyself.ws.GetDepartmentResponse;

/**
 * Asynchronous Client for Department's Web service
 *
 * @author Hyacinthe MENIET
 */
public class AsynchDepartmentWSClient {

    public static void main(String[] args) {
        try {
            if (args == null || args.length < 1) {
                throw new IllegalArgumentException("You must indicate a department code");
            }
            int code = Integer.parseInt(args[0]);

            DepartmentInformationService departInfoService = new DepartmentInformationService();
            DepartmentService departService = departInfoService.getDepartmentServicePort();

            departService.getDepartmentAsync(code, new AsyncHandler<GetDepartmentResponse>() {

                @Override
                public void handleResponse(Response<GetDepartmentResponse> res) {

                    // Asynchronous Invocation
                    if (!res.isCancelled() && res.isDone()) {

                        try {
                            GetDepartmentResponse message = res.get();
                            Department dept = message.getDepartment();
                            System.out.println("Population =" + dept.getPopulation() + " habs, "
                                    + "Surface=" + dept.getSurface() + " km2, "
                                    + "Urbanization=" + dept.getUrbanization());
                        } catch (InterruptedException | ExecutionException ex) {
                            Logger.getLogger(AsynchDepartmentWSClient.class.getName()).log(Level.SEVERE, null, ex);
                        }
                    }
                }
            });

            // give 10 secondes to asynchronous call to complete
            Thread.sleep(10000);
        } catch (InterruptedException ex) {
            Logger.getLogger(AsynchDepartmentWSClient.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
}
